# scs_core
The root of all South Coast Science environmental monitoring applications.

_Contains library classes only._


**Required libraries:** 

* Third party: AWSIoTPythonSDK, pytz, tzlocal


**Branches:**

The stable branch of this repository is master. For deployment purposes, use:

    git clone --branch=master https://github.com/south-coast-science/scs_core.git
